# Release checklist

## Before finalizing release

Make these changes in the main branch before releasing:

* [ ] Ensure all applications/dependencies/charts are at their latest versions
      see `.gitlab/issue_templates/update_all_components.md`
* Update/review `docs/*` and make sure it matches the current state
  * [ ] Update how to checkout the latest stable tag
        `find docs/ -name '*.md' -o -name '*.rst' -exec grep -H '0.7' {} \;`
  * [ ] Document how to upgrade in `docs/upgrading.rst`
* [ ] Update dependencies in `requirements.txt` by following the
      instructions in `requirements.in`
* [ ] Do a manual upgrade test from last release version to `main`
* [ ] Create a release merge request for the main branch

## In the release merge request

* Update [CHANGELOG.md](https://keepachangelog.com)
  * [ ] Include all merged MR since last release, i.e. using [lab](https://github.com/zaquestion/lab#installation):
        ```
        lab mr list -s merged -a | awk '{first = $1; $1=""; print "*" $0, "(" first ")"}'
        ```
  * [ ] Include app charts and versions table (Use [tablemark-cli](https://github.com/haltcase/tablemark-cli)):
        ```
        helm ls -A -o json | jq 'map({name, chart, app_version})' | jq 'map(.chart |= split("-")[-1])' > /tmp/versions.json
        tablemark /tmp/versions.json
        ```
  * [ ] Include `Known issues`
* [ ] Update the version number in the `VERSION` file
* [ ] Commit (signed)
* [ ] Push to MR
* [ ] Make sure main pipeline is successful before merging MR !
* [ ] Wait for MR to get merged into main

## Push a signed tag

* [ ] Make sure the main pipeline succeeds for the last commit before tagging. This
      is important because tags should not get retagged !
* [ ] Create and push signed tag (`git tag -s 0.7.0 -m 'Release 0.7.0'; git push --tags`)

## In the new release branch

* [ ] If this is a major release, create a new release branch (i.e. `v0.7`)

Create a MR for the new branch with the following changes:

* Ensure all dependencies are updated and locked (locking should be done
    only on the release branch):
  * [ ] flux chart versions: `find flux2/* -type f -exec yq eval .spec.chart {} \;`
* [ ] Wait for MR to get merged

## After release

* [ ] Log into <https://readthedocs.org> and update documentation for tagged versions
* [ ] Cherry-pick all changes from the release branch into main which
      shouldn't be only in the 0.4.0 branch (i.e. not the commit locking the
      dependencies)
* [ ] Create an issue for creating a release blog post
* [ ] Create an issue fpr cleaning up
  * old branches/tags
* [ ] Celebrate :clinking_glass: !!
